# Changelog for trivval, the trivial data structure validation library

## 0.2.0 (2021-04-07)

- Allow an optional key to be present with a null value.

## 0.1.1 (2020-09-16)

- Disable two more pylint warnings since we still support Python 2.x.
- Reformat the source code using version 20 of the black tool.

## 0.1.0 (2020-04-14)

- First public release.
